pygeodesy.lcc.Conic

Package pygeodesy :: Module lcc :: Class Conic |
[frames] | no frames]

# Class Conic

      object --+
               |
    named._Named --+
                   |
    named._NamedBase --+
                       |
    named._NamedEnumItem --+
                           |
                          Conic

Lambert conformal conic projection (1- or 2-SP).

Instance Methods
__init__(self, latlon0, par1, par2=None, E0=0, N0=0, k0=1, opt3=0, auth='', **name) New Lambert conformal conic projection. |
convertDatum(self, datum) DEPRECATED, use method Conic.toDatum. |
toDatum(self, datum) Convert this conic to the given datum. |
toStr(self, prec=8, **name) Return this conic as a string. |
Inherited from `named._NamedEnumItem`: `unregister` Inherited from `named._NamedBase`: `__repr__`, `__str__`, `others`, `toRepr` Inherited from `named._Named`: `__format__`, `__imatmul__`, `__matmul__`, `__rmatmul__`, `attrs`, `classof`, `copy`, `dup`, `methodname`, `rename`, `renamed`, `toStr2` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Properties
| auth Get the authentication authority (`str`).
| datum Get the datum (Datum).
| E0 Get the false easting (`meter`).
| k0 Get scale factor (`float`).
| lat0 Get the origin latitude (`degrees90`).
| latlon0 Get the central origin (LatLon2Tuple`(lat, lon)`).
| lam0 Get the central meridian (`radians`).
| lon0 Get the central meridian (`degrees180`).
| N0 Get the false northing (`meter`).
| name2 Get the conic and datum names as "conic.datum" (`str`).
| opt3 Get the optional meridian (`degrees180`).
| par1 Get the 1st standard parallel (`degrees90`).
| par2 Get the 2nd standard parallel (`degrees90`).
| phi0 Get the origin latitude (`radians`).
| philam0 Get the central origin (PhiLam2Tuple`(phi, lam)`).
| SP Get the number of standard parallels (`int`).
Inherited from `named._NamedEnumItem`: `name` Inherited from `named._Named`: `classname`, `classnaming`, `iteration`, `named`, `named2`, `named3`, `named4`, `sizeof`, `typename` Inherited from `object`: `__class__`

Method Details

### __init__ (self, latlon0, par1, par2=None, E0=0, N0=0, k0=1, opt3=0, auth='', **name) (Constructor) |
New Lambert conformal conic projection. Arguments: `latlon0` - Origin with (ellipsoidal) datum (`LatLon`). `par1` - First standard parallel (`degrees90`). `par2` - Optional, second standard parallel (`degrees90`). `E0` - Optional, false easting (`meter`). `N0` - Optional, false northing (`meter`). `k0` - Optional scale factor (`scalar`). `opt3` - Optional meridian (`degrees180`). `auth` - Optional authentication authority (`str`). `name` - Optional `name=NN` for the conic (`str`). Returns: A Lambert projection (Conic). Raises: `TypeError` - Non-ellipsoidal `latlon0`. `ValueError` - Invalid `par1`, `par2`, `E0`, `N0`, `k0` or `opt3`. Overrides: object.__init__

### convertDatum (self, datum) |
DEPRECATED, use method Conic.toDatum. Decorators: `@deprecated_method`

### toDatum (self, datum) |
Convert this conic to the given datum. Arguments: `datum` - Ellipsoidal datum to use (Datum, Ellipsoid, Ellipsoid2 or a_f2Tuple). Returns: Converted conic, unregistered (Conic). Raises: `TypeError` - Non-ellipsoidal `datum`.

### toStr (self, prec=8, **name) |
Return this conic as a string. Arguments: `prec` - Number of (decimal) digits, unstripped (`int`). `name` - Overriding `name=NN` (`str`) or `None` to exclude this conic's name. Returns: Conic attributes (`str`). Overrides: named._Named.toStr

Property Details

### auth Get the authentication authority (`str`). Get method: auth(self) - Get the authentication authority (`str`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### datum Get the datum (Datum). Get method: datum(self) - Get the datum (Datum). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### E0 Get the false easting (`meter`). Get method: E0(self) - Get the false easting (`meter`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### k0 Get scale factor (`float`). Get method: k0(self) - Get scale factor (`float`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### lat0 Get the origin latitude (`degrees90`). Get method: lat0(self) - Get the origin latitude (`degrees90`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### latlon0 Get the central origin (LatLon2Tuple`(lat, lon)`). Get method: latlon0(self) - Get the central origin (LatLon2Tuple`(lat, lon)`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### lam0 Get the central meridian (`radians`). Get method: lam0(self) - Get the central meridian (`radians`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### lon0 Get the central meridian (`degrees180`). Get method: lon0(self) - Get the central meridian (`degrees180`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### N0 Get the false northing (`meter`). Get method: N0(self) - Get the false northing (`meter`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### name2 Get the conic and datum names as "conic.datum" (`str`). Get method: name2(self) - Get the conic and datum names as "conic.datum" (`str`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### opt3 Get the optional meridian (`degrees180`). Get method: opt3(self) - Get the optional meridian (`degrees180`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### par1 Get the 1st standard parallel (`degrees90`). Get method: par1(self) - Get the 1st standard parallel (`degrees90`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### par2 Get the 2nd standard parallel (`degrees90`). Get method: par2(self) - Get the 2nd standard parallel (`degrees90`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### phi0 Get the origin latitude (`radians`). Get method: phi0(self) - Get the origin latitude (`radians`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### philam0 Get the central origin (PhiLam2Tuple`(phi, lam)`). Get method: philam0(self) - Get the central origin (PhiLam2Tuple`(phi, lam)`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### SP Get the number of standard parallels (`int`). Get method: SP(self) - Get the number of standard parallels (`int`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.